@@ -4,4 +4,4 @@ from .fileutil import remove_contents, find_recursive, overwrite, get_memtmpdir
 from .decorators import static_vars
 from .eventutil import EventGenerator, Event
 from .strutil import decomment_cxx, strcompare
-from .plotutil import plot_cdf, plot_linear
\ No newline at end of file
+from .plotutil import plot_cdf, plot_linear, plot_scatter, plot_box
